pub struct AddressBalanceLocation(AddressBalanceLocationInner<NonNegative>);Expand description
Data which Zebra indexes for each transparent::Address.
Currently, Zebra tracks this data 1:1 for each address:
- the balance
Amountfor a transparent address, and - the
AddressLocationfor the firsttransparent::Outputsent to that address (regardless of whether that output is spent or unspent).
All other address data is tracked multiple times for each address (UTXOs and transactions).
Tuple Fields
0: AddressBalanceLocationInner<NonNegative>Implementations
Sourceimpl AddressBalanceLocation
impl AddressBalanceLocation
Sourcepub fn new(first_output: OutputLocation) -> Self
pub fn new(first_output: OutputLocation) -> Self
Creates a new AddressBalanceLocation.
See AddressBalanceLocationInner::new for more details.
Sourcepub fn into_new_change(self) -> AddressBalanceLocationChange
pub fn into_new_change(self) -> AddressBalanceLocationChange
Consumes self and returns a new AddressBalanceLocationChange with
a zero balance, zero received balance, and the location of self.
Methods from Deref<Target = AddressBalanceLocationInner<NonNegative>>
Sourcepub fn balance_mut(&mut self) -> &mut Amount<C>
pub fn balance_mut(&mut self) -> &mut Amount<C>
Returns a mutable reference to the current balance for the address.
Sourcepub fn received_mut(&mut self) -> &mut u64
pub fn received_mut(&mut self) -> &mut u64
Returns a mutable reference to the current received balance for the address.
Sourcepub fn address_location(&self) -> OutputLocation
pub fn address_location(&self) -> OutputLocation
Returns the location of the first transparent::Output sent to an address.
Sourcepub fn height_mut(&mut self) -> &mut Height
pub fn height_mut(&mut self) -> &mut Height
Allows tests to set the height of the address location.