pub struct AddressBalanceLocationInner<C: Constraint + Copy + Debug> {
balance: Amount<C>,
received: u64,
location: OutputLocation,
}Expand description
The inner type of AddressBalanceLocation and AddressBalanceLocationChange.
Fields
balance: Amount<C>The total balance of all UTXOs sent to an address.
received: u64The total balance of all spent and unspent outputs sent to an address.
location: OutputLocationThe location of the first transparent::Output sent to an address.
Implementations
Sourceimpl<C: Constraint + Copy + Debug> AddressBalanceLocationInner<C>
impl<C: Constraint + Copy + Debug> AddressBalanceLocationInner<C>
Sourcepub(crate) fn new(first_output: OutputLocation) -> Self
pub(crate) fn new(first_output: OutputLocation) -> Self
Creates a new AddressBalanceLocationInner from the location of
the first transparent::Output sent to an address.
The returned value has a zero initial balance and received balance.
Sourcepub fn balance_mut(&mut self) -> &mut Amount<C>
pub fn balance_mut(&mut self) -> &mut Amount<C>
Returns a mutable reference to the current balance for the address.
Sourcepub fn received_mut(&mut self) -> &mut u64
pub fn received_mut(&mut self) -> &mut u64
Returns a mutable reference to the current received balance for the address.
Sourcepub fn address_location(&self) -> OutputLocation
pub fn address_location(&self) -> OutputLocation
Returns the location of the first transparent::Output sent to an address.
Sourcepub fn height_mut(&mut self) -> &mut Height
pub fn height_mut(&mut self) -> &mut Height
Allows tests to set the height of the address location.