pub struct AddressTransaction {
address_location: OutputLocation,
transaction_location: TransactionLocation,
}Expand description
A single transaction sent to a transparent::Address.
We store both the address location key and transaction location value in the RocksDB column family key. This improves insert and delete performance.
This requires 8 extra bytes for each transaction location, because we repeat the key for each value. But RocksDB compression reduces the duplicate data size on disk.
Fields
address_location: OutputLocationThe location of the first transparent::Output sent to the address in output.
transaction_location: TransactionLocationThe location of the transaction sent to the address.
Implementations
Sourceimpl AddressTransaction
impl AddressTransaction
Sourcepub fn new(
address_location: OutputLocation,
transaction_location: TransactionLocation,
) -> AddressTransaction
pub fn new( address_location: OutputLocation, transaction_location: TransactionLocation, ) -> AddressTransaction
Create a new AddressTransaction from an address location,
and a transaction location.
Sourcepub fn address_iterator_range(
address_location: OutputLocation,
query: RangeInclusive<Height>,
) -> RangeInclusive<AddressTransaction>
pub fn address_iterator_range( address_location: OutputLocation, query: RangeInclusive<Height>, ) -> RangeInclusive<AddressTransaction>
Create a range of AddressTransactions which starts iteration for the supplied
address. Starts at the first UTXO, or at the query start height, whichever is greater.
Ends at the maximum possible transaction index for the end height.
Used to look up transactions with DiskDb::zs_forward_range_iter.
The transaction locations in the:
- start bound might be invalid, if it is based on the
querystart height. - end bound will always be invalid.
But this is not an issue, since DiskDb::zs_forward_range_iter will fetch all existing
(valid) values in the range.
Sourcepub fn address_iterator_next(&mut self)
pub fn address_iterator_next(&mut self)
Update the transaction location to the next possible transaction for the
supplied address. Used to look up the next output with
ReadDisk::zs_next_key_value_from.
The updated transaction location may be invalid, which is not an issue
since ReadDisk::zs_next_key_value_from will fetch the next
existing (valid) value.
Sourcepub fn address_location(&self) -> OutputLocation
pub fn address_location(&self) -> OutputLocation
The location of the first transparent::Output sent to the address of this output.
This can be used to look up the address.
Sourcepub fn transaction_location(&self) -> TransactionLocation
pub fn transaction_location(&self) -> TransactionLocation
The location of this transaction.
Sourcepub fn address_location_mut(&mut self) -> &mut OutputLocation
pub fn address_location_mut(&mut self) -> &mut OutputLocation
Allows tests to modify the address location.
Sourcepub fn transaction_location_mut(&mut self) -> &mut TransactionLocation
pub fn transaction_location_mut(&mut self) -> &mut TransactionLocation
Allows tests to modify the unspent output location.